=======================
Assets module for Ralph
=======================

.. image:: https://pypip.in/v/ralph_assets/badge.png
    :target: https://crate.io/packages/ralph_assets/
    :alt: Latest PyPI version


.. image:: https://pypip.in/d/ralph_assets/badge.svg
    :target: https://crate.io/packages/ralph_assets/
    :alt: Number of PyPI downloads


.. image:: https://travis-ci.org/allegro/ralph_assets.svg?branch=develop
    :target: https://travis-ci.org/allegro/ralph_assets


.. image:: https://coveralls.io/repos/allegro/ralph_assets/badge.png?branch=develop
  :target: https://coveralls.io/r/allegro/ralph_assets?branch=develop


.. image:: https://pypip.in/license/ralph_assets/badge.svg
    :target: https://crate.io/packages/ralph_assets/


Assets module brings Offline Stock management functionality to the Ralph.
It maintains ordering, purchasing and releasing the device to the user.
It is not limited to datacenter. You can maintain processes for backoffice assets 
as well.

Ralph is an asset management system for your data center. It lets you see what
hardware and software is installed. It also lets you keep track of who is using
every device, for what, and how much it costs.

